@@ -13,7 +13,7 @@ use std::io;
 use ratatui::{
     backend::{Backend, WindowSize},
     buffer::Cell,
-    layout::{Rect, Size},
+    layout::{Position, Size},
 };
 
 pub struct RawTerminalBackend {}
@@ -31,11 +31,11 @@ impl Backend for RawTerminalBackend {
         Ok(())
     }
 
-    fn get_cursor(&mut self) -> io::Result<(u16, u16)> {
-        Ok((0, 0))
+    fn get_cursor_position(&mut self) -> io::Result<Position> {
+        Ok(Position::new(0, 0))
     }
 
-    fn set_cursor(&mut self, _x: u16, _y: u16) -> io::Result<()> {
+    fn set_cursor_position<P: Into<Position>>(&mut self, _position: P) -> io::Result<()> {
         Ok(())
     }
 
@@ -46,8 +46,8 @@ impl Backend for RawTerminalBackend {
         Ok(())
     }
 
-    fn size(&self) -> io::Result<Rect> {
-        Ok(Rect::new(0, 0, 0, 0))
+    fn size(&self) -> io::Result<Size> {
+        Ok(Size::new(0, 0))
     }
 
     fn window_size(&mut self) -> io::Result<WindowSize> {
